import os

class Config:
    DEBUG = True # Enable/disable debuf mode.

    # Generate a nice key using secrets.token_urlsafe()
    SECRET_KEY = os.environ.get("SECRET_KEY", "FaHW65b6vBDGlhazs-8JZHb4jiZvI_9jj6hcUa_EV1Q")

    # Generate a good salt using: secrets.SystemRandom().getrandbits(128)
    SECURITY_PASSWORD_SALT = os.environ.get("SECURITY_PASSWORD_SALT", "327589938147555935984237744799432734422")

    # Name of session cookie
    SESSION_COOKIE_NAME = "session"

    # Database configuration
    SQLALCHEMY_DATABASE_URI = 'sqlite://' # In-memory SQLite database
    SQLALCHEMY_ECHO = False

    # Flask-Security Configurations
    SECURITY_CONFIRMABLE = False  # Disable email confirmation
    SECURITY_USERNAME_ENABLE = True  # Enable username for user accounts.
    SECURITY_USERNAME_REQUIRED = True # Require username when registering a new user.
    SECURITY_USERNAME_MAX_LENGTH = 20  # Maximum allowed length for usernames.
    SECURITY_PASSWORD_LENGTH_MIN = 5  # Minimum password length for user accounts
    SECURITY_SEND_REGISTER_EMAIL = False  # Specifies whether registration email is sent.
    SECURITY_REGISTERABLE = True  # Allow registration of new users without confirmation

    # Arguments for the email validator
    SECURITY_EMAIL_VALIDATOR_ARGS = {"test_environment": DEBUG}


    # No forms so no concept of flashing
    SECURITY_FLASH_MESSAGES = False

    # Enforce CSRF protection for session / browser - but allow token-based
    # API calls to go through
    #SECURITY_CSRF_PROTECT_MECHANISMS = ["session", "basic"]
    #SECURITY_CSRF_IGNORE_UNAUTH_ENDPOINTS = True # If True then CSRF will not be required for endpoints that don’t require authentication (e.g. login, logout, register, forgot_password).
    #SECURITY_CSRF_COOKIE_NAME = "X-XSRF-Token" # The name for the CSRF cookie
    #WTF_CSRF_TIME_LIMIT = None # Don't have csrf tokens expire (they are invalid after logout)
    #SECURITY_REDIRECT_BEHAVIOR = "spa"
    #WTF_CSRF_CHECK_DEFAULT = False
    #WTF_CSRF_TIME_LIMIT = None

    # Define the Content Security Policy (CSP). Helps protect against various types of attacks.
    csp = {
        'default-src': [
            '\'self\'',
            'https://fonts.googleapis.com',
            'https://fonts.gstatic.com',
        ],
        'style-src': [
            '\'self\'',
            '\'unsafe-inline\'',
            'https://fonts.googleapis.com',
        ]
    }