import pandas as pd
import numpy as np

# File which reformats existing data into parsable data by the app.py

def parse_swe_election_data():
    df = pd.read_csv("../data/Riksdagsval - valresultat, antal röster efter region, parti mm och valår.csv",
                    sep=';',
                    skiprows=0,
                    skipfooter=1,
                    engine="python")

    
    years = df.columns[4:] #['1973','1976','1979','1982','1985','1988','1991','1994','1998','2002','2006','2010','2014','2018','2022']

    votes_in_county = {}
    current_county_code = None 

    for row in range(len(df)):
        county_code = df.loc[row]["Länskod"]

        if not pd.isna(county_code): # Check if the variable is a county code and not a nan
            current_county_code = int(county_code)
            county_name = df.loc[row]["Län"]

            if current_county_code not in votes_in_county:
                votes_in_county[current_county_code] = {
                    "county_name": county_name,
                    "parties": {},
                    "total_votes": 0
                }

        # Each row contains votes for a party
        party_abbreviation = df.loc[row]["Parti"] # M, C, FP, KD, MP, S, V, SD, ÖVRIGA, OGILTIGA, VALSKOLKARE
        party_name = df.loc[row]["Partinamn"]

        votes_in_county[current_county_code]["parties"][party_name] = {
            "votes_per_year" :  {}
        }

        for year in years:
            
            votes = df.loc[row][year]
            if pd.isna(votes):
                votes = 0
            else:
                votes = int(votes)
             

            votes_in_county[current_county_code]["parties"][party_name]["votes_per_year"][year] = votes

            # Add votes to total voters if not OGILTIGA or VALSKOLKARE
            if party_abbreviation not in ["OGILTIGA", "VALSKOLKARE"]:
                votes_in_county[current_county_code]["total_votes"] += votes

    return votes_in_county


def parse_swe_demographic_data():
    chartData = {
            1 : {
                "1991" : 254.9,
                "1992" : 257.3,
                "1993" : 259.8,
                "1994" : 263.2,
                "1995" : 265.9,
                "1996" : 268.8,
                "1997" : 271.6,
                "1998" : 274.8,
                "1999" : 276.6,
                "2000" : 279.7,
                "2001" : 282.1,
                "2002" : 283.8,
                "2003" : 285.4,
                "2004" : 287.3,
                "2005" : 289.9,
                "2006" : 294.2,
                "2007" : 299.0,
                "2008" : 303.9,
                "2009" : 309.7,
                "2010" : 315.1,
                "2011" : 320.5,
                "2012" : 325.9,
                "2013" : 331.4,
                "2014" : 336.9,
                "2015" : 342.0,
                "2016" : 347.8,
                "2017" : 353.8,
                "2018" : 359.9,
            },
            3: {
                "1991" : 39.2,
                "1992" : 39.9,
                "1993" : 40.5,
                "1994" : 41.0,
                "1995" : 41.3,
                "1996" : 41.4,
                "1997" : 41.6,
                "1998" : 41.7,
                "1999" : 41.6,
                "2000" : 41.8,
                "2001" : 42.2,
                "2002" : 42.4,
                "2003" : 42.7,
                "2004" : 43.0,
                "2005" : 43.3,
                "2006" : 39.0,
                "2007" : 39.4,
                "2008" : 39.9,
                "2009" : 40.4,
                "2010" : 40.9,
                "2011" : 41.3,
                "2012" : 41.7,
                "2013" : 42.2,
                "2014" : 42.6,
                "2015" : 43.2,
                "2016" : 44.1,
                "2017" : 45.1,
                "2018" : 46.0,
            },
            4: {
                "1991" : 42.4,
                "1992" : 42.5,
                "1993" : 42.8,
                "1994" : 42.9,
                "1995" : 42.7,
                "1996" : 42.5,
                "1997" : 42.4,
                "1998" : 42.3,
                "1999" : 41.9,
                "2000" : 42.0,
                "2001" : 42.1,
                "2002" : 42.4,
                "2003" : 42.7,
                "2004" : 42.8,
                "2005" : 42.9,
                "2006" : 43.1,
                "2007" : 43.5,
                "2008" : 43.8,
                "2009" : 44.1,
                "2010" : 44.4,
                "2011" : 44.9,
                "2012" : 45.2,
                "2013" : 45.7,
                "2014" : 46.2,
                "2015" : 46.7,
                "2016" : 47.4,
                "2017" : 48.0,
                "2018" : 48.5,
            },
            5: {
                "1991" : 38.4,
                "1992" : 38.7,
                "1993" : 38.9,
                "1994" : 39.3,
                "1995" : 39.4,
                "1996" : 39.4,
                "1997" : 39.2,
                "1998" : 39.0,
                "1999" : 38.8,
                "2000" : 38.8,
                "2001" : 38.9,
                "2002" : 39.0,
                "2003" : 39.1,
                "2004" : 39.2,
                "2005" : 39.3,
                "2006" : 39.4,
                "2007" : 39.7,
                "2008" : 39.9,
                "2009" : 40.3,
                "2010" : 40.5,
                "2011" : 40.9,
                "2012" : 41.1,
                "2013" : 41.5,
                "2014" : 41.9,
                "2015" : 42.2,
                "2016" : 42.8,
                "2017" : 43.3,
                "2018" : 43.7,
            },
            6: {
                "1991" : 31.2,
                "1992" : 31.2,
                "1993" : 31.3,
                "1994" : 31.4,
                "1995" : 31.5,
                "1996" : 31.4,
                "1997" : 31.3,
                "1998" : 31.3,
                "1999" : 31.2,
                "2000" : 31.2,
                "2001" : 31.2,
                "2002" : 31.2,
                "2003" : 31.3,
                "2004" : 31.4,
                "2005" : 31.5,
                "2006" : 31.6,
                "2007" : 31.8,
                "2008" : 31.9,
                "2009" : 32.0,
                "2010" : 32.1,
                "2011" : 32.4,
                "2012" : 32.4,
                "2013" : 32.7,
                "2014" : 33.0,
                "2015" : 33.3,
                "2016" : 33.8,
                "2017" : 34.2,
                "2018" : 34.6,
            },
            7: {
                "1991": 21.1,
                "1992": 21.2,
                "1993": 21.2,
                "1994": 21.4,
                "1995": 21.3,
                "1996": 21.2,
                "1997": 21.2,
                "1998": 21.1,
                "1999": 20.9,
                "2000": 20.9,
                "2001": 20.9,
                "2002": 20.9,
                "2003": 21.0,
                "2004": 21.1,
                "2005": 21.1,
                "2006": 21.2,
                "2007": 21.3,
                "2008": 21.5,
                "2009": 21.6,
                "2010": 21.7,
                "2011": 21.9,
                "2012": 22.0,
                "2013": 22.2,
                "2014": 22.5,
                "2015": 22.7,
                "2016": 23.1,
                "2017": 23.4,
                "2018": 23.7,
            },
            8: {
                "1991": 21.7,
                "1992": 21.7,
                "1993": 21.7,
                "1994": 21.8,
                "1995": 21.8,
                "1996": 21.7,
                "1997": 21.5,
                "1998": 21.3,
                "1999": 21.1,
                "2000": 21.0,
                "2001": 20.9,
                "2002": 20.9,
                "2003": 20.9,
                "2004": 20.9,
                "2005": 20.9,
                "2006": 20.8,
                "2007": 20.8,
                "2008": 20.8,
                "2009": 20.8,
                "2010": 20.8,
                "2011": 20.9,
                "2012": 20.9,
                "2013": 21.0,
                "2014": 21.1,
                "2015": 21.3,
                "2016": 21.7,
                "2017": 21.8,
                "2018": 21.9,
            },
           9: {
                "1991": 18.3,
                "1992": 18.3,
                "1993": 18.4,
                "1994": 18.5,
                "1995": 18.5,
                "1996": 18.5,
                "1997": 18.4,
                "1998": 18.4,
                "1999": 18.2,
                "2000": 18.2,
                "2001": 18.2,
                "2002": 18.2,
                "2003": 18.3,
                "2004": 18.3,
                "2005": 18.2,
                "2006": 18.2,
                "2007": 18.1,
                "2008": 18.1,
                "2009": 18.2,
                "2010": 18.2,
                "2011": 18.3,
                "2012": 18.2,
                "2013": 18.2,
                "2014": 18.3,
                "2015": 18.3,
                "2016": 18.5,
                "2017": 18.7,
                "2018": 18.9,
            },
            10: {
                "1991" : 51.4,
                "1992" : 51.4,
                "1993" : 51.6,
                "1994" : 52.0,
                "1995" : 51.9,
                "1996" : 51.7,
                "1997" : 51.6,
                "1998" : 51.5,
                "1999" : 51.1,
                "2000" : 51.0,
                "2001" : 50.9,
                "2002" : 50.9,
                "2003" : 50.9,
                "2004" : 51.0,
                "2005" : 51.1,
                "2006" : 51.4,
                "2007" : 51.5,
                "2008" : 51.7,
                "2009" : 51.8,
                "2010" : 52.0,
                "2011" : 52.2,
                "2012" : 51.9,
                "2013" : 52.1,
                "2014" : 52.6,
                "2015" : 53.3,
                "2016" : 54.1,
                "2017" : 54.4,
                "2018" : 54.5,
            },
            12: {
                "1991" : 97.8,
                "1992" : 98.5,
                "1993" : 99.2,
                "1994" : 100.3,
                "1995" : 100.8,
                "1996" : 101.1,
                "1997" : 101.3,
                "1998" : 101.6,
                "1999" : 101.8,
                "2000" : 102.3,
                "2001" : 103.0,
                "2002" : 103.8,
                "2003" : 104.5,
                "2004" : 105.2,
                "2005" : 106.0,
                "2006" : 107.3,
                "2007" : 108.7,
                "2008" : 110.1,
                "2009" : 111.6,
                "2010" : 112.7,
                "2011" : 114.2,
                "2012" : 115.1,
                "2013" : 116.2,
                "2014" : 117.5,
                "2015" : 118.9,
                "2016" : 120.8,
                "2017" : 122.6,
                "2018" : 124.2,
            },
            13: {
                "1991" : 47.3,
                "1992" : 47.9,
                "1993" : 48.5,
                "1994" : 49.1,
                "1995" : 49.4,
                "1996" : 49.5,
                "1997" : 49.7,
                "1998" : 50.0,
                "1999" : 50.1,
                "2000" : 50.4,
                "2001" : 50.7,
                "2002" : 51.0,
                "2003" : 51.5,
                "2004" : 52.0,
                "2005" : 52.3,
                "2006" : 52.9,
                "2007" : 53.4,
                "2008" : 53.8,
                "2009" : 54.3,
                "2010" : 54.8,
                "2011" : 55.6,
                "2012" : 56.0,
                "2013" : 56.5,
                "2014" : 57.2,
                "2015" : 58.0,
                "2016" : 59.0,
                "2017" : 59.9,
                "2018" : 60.7,       
            },
            14: {
                "1991" : 60.5,
                "1992" : 60.8,
                "1993" : 61.2,
                "1994" : 61.7,
                "1995" : 61.9,
                "1996" : 62.0,
                "1997" : 62.1,
                "1998" : 62.1,
                "1999" : 62.1,
                "2000" : 62.4,
                "2001" : 62.7,
                "2002" : 63.0,
                "2003" : 63.2,
                "2004" : 63.5,
                "2005" : 63.8,
                "2006" : 64.2,
                "2007" : 64.6,
                "2008" : 65.0,
                "2009" : 65.5,
                "2010" : 66.0,
                "2011" : 66.8,
                "2012" : 67.2,
                "2013" : 67.9,
                "2014" : 68.6,
                "2015" : 69.3,
                "2016" : 70.2,
                "2017" : 71.0,
                "2018" : 71.8,
            },
            17: {
                "1991" : 16.2,
                "1992" : 16.2,
                "1993" : 16.2,
                "1994" : 16.2,
                "1995" : 16.1,
                "1996" : 16.0,
                "1997" : 15.9,
                "1998" : 15.8,
                "1999" : 15.7,
                "2000" : 15.6,
                "2001" : 15.6,
                "2002" : 15.5,
                "2003" : 15.6,
                "2004" : 15.6,
                "2005" : 15.5,
                "2006" : 15.5,
                "2007" : 15.6,
                "2008" : 15.5,
                "2009" : 15.5,
                "2010" : 15.5,
                "2011" : 15.6,
                "2012" : 15.5,
                "2013" : 15.6,
                "2014" : 15.7,
                "2015" : 15.7,
                "2016" : 15.9,
                "2017" : 16.0,
                "2018" : 16.1,
             },
            18: {
                "1991": 32.1,
                "1992": 32.2,
                "1993": 32.3,
                "1994": 32.5,
                "1995": 32.5,
                "1996": 32.4,
                "1997": 32.3,
                "1998": 32.2,
                "1999": 32.0,
                "2000": 32.0,
                "2001": 32.0,
                "2002": 32.0,
                "2003": 32.1,
                "2004": 32.1,
                "2005": 32.1,
                "2006": 32.2,
                "2007": 32.3,
                "2008": 32.5,
                "2009": 32.6,
                "2010": 32.8,
                "2011": 33.1,
                "2012": 33.2,
                "2013": 33.6,
                "2014": 33.9,
                "2015": 34.2,
                "2016": 34.7,
                "2017": 35.1,
                "2018": 35.5,
            },
            19: {
                "1991": 41.2,
                "1992": 41.3,
                "1993": 41.4,
                "1994": 41.5,
                "1995": 41.4,
                "1996": 41.3,
                "1997": 41.0,
                "1998": 40.9,
                "1999": 40.7,
                "2000": 40.7,
                "2001": 40.8,
                "2002": 41.0,
                "2003": 41.2,
                "2004": 41.3,
                "2005": 41.4,
                "2006": 48.3,
                "2007": 48.4,
                "2008": 48.6,
                "2009": 48.9,
                "2010": 49.1,
                "2011": 49.7,
                "2012": 50.0,
                "2013": 50.6,
                "2014": 51.1,
                "2015": 51.6,
                "2016": 52.3,
                "2017": 53.0,
                "2018": 53.5,
            },
            20: {
                "1991" : 10.3,
                "1992" : 10.3,
                "1993" : 10.3,
                "1994" : 10.3,
                "1995" : 10.3,
                "1996" : 10.2,
                "1997" : 10.1,
                "1998" : 10.0,
                "1999" : 10.0,
                "2000" : 9.9,
                "2001" : 9.8,
                "2002" : 9.8,
                "2003" : 9.8,
                "2004" : 9.8,
                "2005" : 9.8,
                "2006" : 9.8,
                "2007" : 9.8,
                "2008" : 9.8,
                "2009" : 9.8,
                "2010" : 9.8,
                "2011" : 9.9,
                "2012" : 9.8,
                "2013" : 9.9,
                "2014" : 10.0,
                "2015" : 10.0,
                "2016" : 10.2,
                "2017" : 10.2,
                "2018" : 10.2,
            },
            21: {
                "1991" : 15.9,
                "1992" : 15.9,
                "1993" : 15.9,
                "1994" : 15.9,
                "1995" : 15.9,
                "1996" : 15.8,
                "1997" : 15.6,
                "1998" : 15.5,
                "1999" : 15.4,
                "2000" : 15.3,
                "2001" : 15.3,
                "2002" : 15.2,
                "2003" : 15.2,
                "2004" : 15.2,
                "2005" : 15.2,
                "2006" : 15.1,
                "2007" : 15.1,
                "2008" : 15.2,
                "2009" : 15.2,
                "2010" : 15.2,
                "2011" : 15.2,
                "2012" : 15.2,
                "2013" : 15.3,
                "2014" : 15.5,
                "2015" : 15.6,
                "2016" : 15.7,
                "2017" : 15.8,
                "2018" : 15.8,
                    
            },
            22: {
                "1991": 12.1,
                "1992": 12.0,
                "1993": 12.0,
                "1994": 12.0,
                "1995": 11.9,
                "1996": 11.8,
                "1997": 11.7,
                "1998": 11.6,
                "1999": 11.5,
                "2000": 11.4,
                "2001": 11.3,
                "2002": 11.3,
                "2003": 11.3,
                "2004": 11.3,
                "2005": 11.2,
                "2006": 11.3,
                "2007": 11.2,
                "2008": 11.2,
                "2009": 11.2,
                "2010": 11.2,
                "2011": 11.2,
                "2012": 11.2,
                "2013": 11.2,
                "2014": 11.3,
                "2015": 11.3,
                "2016": 11.4,
                "2017": 11.4,
                "2018": 11.4,
            },
            23: {
                "1991" : 2.8,
                "1992" : 2.7,
                "1993" : 2.8,
                "1994" : 2.8,
                "1995" : 2.7,
                "1996" : 2.7,
                "1997" : 2.7,
                "1998" : 2.7,
                "1999" : 2.6,
                "2000" : 2.6,
                "2001" : 2.6,
                "2002" : 2.6,
                "2003" : 2.6,
                "2004" : 2.6,
                "2005" : 2.6,
                "2006" : 2.6,
                "2007" : 2.6,
                "2008" : 2.6,
                "2009" : 2.6,
                "2010" : 2.6,
                "2011" : 2.6,
                "2012" : 2.5,
                "2013" : 2.6,
                "2014" : 2.6,
                "2015" : 2.6,
                "2016" : 2.6,
                "2017" : 2.7,
                "2018" : 2.7,
            },
            24: {
                "1991": 4.6,
                "1992": 4.6,
                "1993": 4.7,
                "1994": 4.7,
                "1995": 4.7,
                "1996": 4.7,
                "1997": 4.7,
                "1998": 4.7,
                "1999": 4.7,
                "2000": 4.6,
                "2001": 4.6,
                "2002": 4.6,
                "2003": 4.6,
                "2004": 4.7,
                "2005": 4.7,
                "2006": 4.7,
                "2007": 4.7,
                "2008": 4.7,
                "2009": 4.7,
                "2010": 4.7,
                "2011": 4.7,
                "2012": 4.7,
                "2013": 4.8,
                "2014": 4.8,
                "2015": 4.8,
                "2016": 4.9,
                "2017": 4.9,
                "2018": 4.9,  
            },
            25: {
                "1991": 2.7,
                "1992": 2.7,
                "1993": 2.7,
                "1994": 2.7,
                "1995": 2.7,
                "1996": 2.7,
                "1997": 2.7,
                "1998": 2.6,
                "1999": 2.6,
                "2000": 2.6,
                "2001": 2.6,
                "2002": 2.6,
                "2003": 2.6,
                "2004": 2.6,
                "2005": 2.6,
                "2006": 2.6,
                "2007": 2.6,
                "2008": 2.5,
                "2009": 2.5,
                "2010": 2.5,
                "2011": 2.6,
                "2012": 2.5,
                "2013": 2.6,
                "2014": 2.6,
                "2015": 2.6,
                "2016": 2.6,
                "2017": 2.6,
                "2018": 2.6
            }
        }
                  
    return chartData
    
a = parse_swe_election_data()
print(a[1]["total_votes"])
