import React, { useState, useEffect, useMemo } from 'react';
import Autocomplete from '@mui/material/Autocomplete';
import TextField from '@mui/material/TextField';
import MultiLevelOptions from './MultiLevelOptions'
import "../../Css/Search.css";

export const SearchComponent = ({ data, changeRegion }) => {

  // State to keep track of the currently selected province
  const [selectedProvince, setSelectedProvince] = useState(null);

  changeRegion(selectedProvince)

  // Array of province options for the autocomplete component.
  const provinceOptions = [
      'Stockholm', 'Uppsala', 'Södermanland', 'Östergötland', 'Jönköping',
      'Kronoberg', 'Kalmar', 'Gotland', 'Blekinge', 'Skåne', 'Halland',
      'Västra Götaland', 'Värmland', 'Örebro', 'Västmanland', 'Dalarna',
      'Gävleborg', 'Västernorrland', 'Jämtland', 'Västerbotten', 'Norrbotten'
  ];

  useEffect(() => {
    if (data && provinceOptions.includes(data)) {
      setSelectedProvince(data);
    } else {
      setSelectedProvince(null);
    }
  }, [data]); //useEffect runs when the 'data' changes

  const handleProvinceChange = (event, newValue) => {
    setSelectedProvince(newValue);
  };

  const isOptionEqualToValue = (option, value) => option === value;
  const memoizedProvince = useMemo(() => selectedProvince, [selectedProvince]);

return (
    <div>
      {/* Autocomplete component for selecting a province */}
      <Autocomplete  
        disablePortal
        id="combo-box-demo"
        options={provinceOptions}
        value={memoizedProvince}
        onChange={handleProvinceChange}
        getOptionSelected={isOptionEqualToValue} // Custom equality test
        sx={{ 
          width: 350,
          marginTop: "15px",
          '& .MuiInputBase-root': {
            backgroundColor: '#3D96B1', // Ensure background color applies to the input itself
            color: "#061525",
            fontSize: "20px",
            marginTop: "20px",
            fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;"
          },
          '& .MuiButtonBase-root svg' : {
            background: "#061525",

          },
          '& .MuiOutlinedInput-root' : {
            border: "1px solid white" //Ensure smooth transitions between borders
          },
          '& .MuiOutlinedInput-notchedOutline' : {
            display: "none", //Remove the notched border
          },
          '& .MuiOutlinedInput-root.Mui-focused' : {
            border: "1px solid white"
          },
          '& .MuiOutlinedInput-root:hover' : {
            border: "1px solid white"
          },
          '& .MuiButtonBase-root' : {
            color: "white",
          }
        }}
        renderInput={(params) => (
          <TextField 
              {...params} 
              label="County"
              InputLabelProps={{
                sx: {
                  fontSize: '36px', // Change font size of the label
                  fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;",
                  fontWeight: 700,

                  color: "white",
                  marginTop: '10px',
                  transform: 'translateY(-44px) scale(1)',
                  '&.Mui-focused': {color:"#3D96B1",
                                    fontSize: '36px',
                                    transform: 'translateY(-44px) scale(1)', // Move the label further up
                  },
                  
                  '&.MuiInputLabel-shrink' : {transform: 'translateY(-44px) scale(1)', // Move the label further up
                                              fontSize: '36px',
                  },                
                },
              }}
          />
        )}
      />

      {/* Component for multi-level options */}
      <div className='multi_select'>
        <MultiLevelOptions />
        
      </div>
    </div>  
  );
};

export default SearchComponent;
