import '../../Css/Dashboard.css';
import React, { useState, useEffect, useContext } from 'react';
import TopNavBar from '../../Components/Navbar/Navbar';
import Map from './Map';
import Visualiser from './Visualiser';
import { SearchComponent } from '../../Components/Search/SearchComponent';
import { GlobalContext } from '../../Context/GlobalContext';

export const Dashboard = () => {
  const [data, setData] = useState({ label: "", id: "" });
  const [region, setRegion] = useState({}); // State to store the currently selected region
  const [displayMap, setDisplayMap] = useState(true); // State variable to track the currently displayed component
  const {loggedInStatus} = useContext(GlobalContext);

  const handlerFunction = (Region_data) => {
    setData(Region_data);
  };

  const changeRegion = (regionName) => {
    // Update the region state to trigger re-render and change the color of the specified region's path
    setRegion(regionName);
    handlerFunction(data);
  };

  const toggleDisplay = () => {
    setDisplayMap(!displayMap); // Toggle the displayMap state, not currently used
  };

  useEffect(() => {
    console.log("loggedInStatus = " + loggedInStatus);
  }, []);

  return (

    /* Container for the entire page, which is reached after logon */
    <div className='dashboard'>

      {/* Render the top navigation bar */}
      <TopNavBar toggleDisplay = {toggleDisplay} displayMap = {displayMap} />
     
      <div className='container'>
        {/* Render the search component */}
        <div className='search_container'>
          <SearchComponent data={data.label} changeRegion={changeRegion} />
        </div>
      
        {/* Render the map component */}
        <div className='map_container' id="d3_map">
          <Map handlerFunction={handlerFunction} selectedRegion={region} />
        </div>

        {/* Render the visualizer component */}
        <div className='table_container'>
          <Visualiser Regiondata={data} />
        </div>
      </div>
    </div>
  );
};
