import React, { useState, useContext, useEffect } from 'react';
import axios from 'axios';
import '../../Css/SignForm.css';
import '../Dashboard/Dashboard.jsx'
//React-icons imports
import { FaUser } from "react-icons/fa";
import { FaLock } from "react-icons/fa";

import { useNavigate } from 'react-router-dom'; // Import useNavigate hook
import { GlobalContext } from '../../Context/GlobalContext';

export const SignInForm = ({ onRegisterClick }) => {
  const [username, setUsername] = useState('');
  const [password, setPassword] = useState('');
  const [errorMessages, setErrorMessages] = useState([]);
  const {serverAddress, serverPort, loggedInStatus, setLoggedInStatus} = useContext(GlobalContext);
  const navigate = useNavigate();

  const handleLoginClick = () => {
    // Call the onLoginClick function passed as prop
    onRegisterClick();
  };
  const handleUsernameChange = (e) => {
    setUsername(e.target.value);
  };

  const handlePasswordChange = (e) => {
    setPassword(e.target.value);
  };

  // Check if user is already logged in when the component mounts
  useEffect(() => {
    const checkAuthentication = async () => {
      try {
        // Send a POST request to the server to authenticate the user
        const response = await axios.post(serverAddress + ':' + serverPort + '/api/authenticate', {
          withCredentials: true, // Include credentials (cookies) in the request
          headers: {
              'Content-Type': 'application/json', 
          },
        });

        if (response.data.success) {
          setLoggedInStatus(true); // Set the logged-in status in global context
          navigate('/dashboard'); // Redirect user to the dashboard page when successful
        }
        
      } catch (error) {
        // Do nothing
      }
    };

    checkAuthentication();
  }, []);

  const handleSubmit = async (e) => {
    e.preventDefault();

    // Prepare login data
    const loginData = {
      username,
      password
    };

    try {
      // Send a POST request to the server to login the user
      const response = await axios.post(serverAddress + ':' + serverPort + '/api/login', loginData, {
        headers: {
            'Content-Type': 'application/json', 
        },
      });

      if (response.data.success) {
        setErrorMessages([]); // Clear any error messages
        setLoggedInStatus(true); // Set the logged-in status in global context
        navigate('/dashboard'); // Redirect user to the dashboard page when successful
      } else {
        setErrorMessages(response.data.errors); // Display errors returned from the server
      }

    } catch (error) {
      setErrorMessages(['An unexpected error occurred.']); 
    }
  };

  return (
    <div className='wrapper'>
        <form onSubmit={handleSubmit}>    
            <h1>Login</h1>

            {/* Display error messages */}
            {errorMessages.length > 0 && (
                    <ul className="error-messages">
                        {errorMessages.map((msg, index) => (
                            <li key={index} className="error-message">{msg}</li>
                        ))}
                    </ul>
            )}

            {/* Username input field */}
            <div className="input-box">
                <input type="text" placeholder='Username' value={username} onChange={handleUsernameChange} required/>
                <FaUser className='icon'/>
            </div>

            {/* Password input field */}
            <div className="input-box">
                <input type="password" placeholder='Password' value={password} onChange={handlePasswordChange} required/>
                <FaLock className='icon'/>
            </div>

            {/*
            Must implement email confirmation upon registration for this to working.
            <div className="remember-forget">
                <label><input type="checkbox" />Remember me</label>
                <a href="#">Forget password?</a>
            </div>
            */}

            {/* Submit button for login */}
            <button type='submit'>Login</button>
            <div className="register-link">
                <p>Don't have an account? <a href="#" onClick={handleLoginClick}>Register</a></p>
            </div>
        </form>

    </div>
  );
};
