import React from 'react';
import ReactDOM from 'react-dom/client';
import './Css/index.css';
import { Dashboard } from './Pages/Dashboard/Dashboard';
import Form from './Pages/SignupSigninForms/Form.js';
import { BrowserRouter, Routes, Route, Navigate } from 'react-router-dom';
import GlobalContextProvider from './Context/GlobalContext.js';
import ProtectedRoute  from './Pages/protected.js';

const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(
  //Implement routing from sign forms to dashboard
  <React.StrictMode>
    {/* The GlobalContextProvider provides various variables that are reached from every component */}
    <GlobalContextProvider> 
      <BrowserRouter>
        <Routes>
            <Route element={<ProtectedRoute />} >
              {/* Child elements are protected. Non authenticated users are redirected to "/" */}
              <Route path="dashboard" element={<Dashboard />} /> {/* Page accessible after logon */}
            </Route>

            <Route path='/' element={<Form/>} /> {/* Login & Register Page */}
            <Route path="*" element={<Navigate to="/" />} /> {/* Redirect all other requests to the page "/" */}
         </Routes>
      </BrowserRouter>
    </GlobalContextProvider>
  </React.StrictMode>
);



